# action - manage igor actions

This plugin is an absolutely minimal user interface to allow inspection of
the current set of Igor actions, and adding, deleting and changing those actions.

You should be logged in as *admin* to use it.

